@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp qw( croak );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 my @tone_list = ('C', 'C#', 'D', 'D#', 'E', 'F', 'F#', 'G', 'G#', 'A', 'A#', 'B',
                  'C', 'C#', 'D', 'D#', 'E', 'F', 'F#', 'G', 'G#', 'A', 'A#', 'B');
@@ -37,6 +37,7 @@ my $base_chord_list = {
     '11'       => '0,4,7,10,14,17',
     '13'       => '0,4,7,10,14,17,21',
     'm'        => '0,3,7',
+    'madd4'    => '0,3,5,7',
     'm6'       => '0,3,7,9',
     'm6(9)'    => '0,3,7,9,14',          'm69'     => '0,3,7,9,14',
     'mM7'      => '0,3,7,11',
@@ -49,7 +50,7 @@ my $base_chord_list = {
     'm11'      => '0,3,7,10,14,17',
     'm13'      => '0,3,7,10,14,17,21',
     'dim'      => '0,3,6',
-    'dim7'     => '0,3,6,9',
+    'dim7'     => '0,3,6,9',            'dim6'     => '0,3,6,9',
     'aug'      => '0,4,8',
     'aug7'     => '0,4,8,10',
     'augM7'    => '0,4,8,11',
